import React from "react";
import { IAnalyticalBackend, IRequestCorrelationMetadata } from "@gooddata/sdk-backend-spi";
/**
 * Props of the {@link CorrelationProvider} component.
 * @public
 */
export interface ICorrelationProviderProps {
    /**
     * Key-value pairs of correlation metadata to be used for telemetry
     */
    correlationData: Record<string, string>;
    /**
     * React children
     */
    children?: React.ReactNode;
}
/**
 * CorrelationProvider provides request correlation metadata to components.
 * When nested, correlation metadata from ancestor providers is merged with the current provider.
 *
 * @public
 */
export declare const CorrelationProvider: React.FC<ICorrelationProviderProps>;
/**
 * Hook to get correlation metadata from the nearest correlation provider.
 *
 * @public
 */
export declare const useCorrelationData: () => Record<string, string>;
/**
 * Hook to get a backend instance with correlation metadata from context,
 * and optionally merge them with additional correlation metadata provided as a parameter.
 *
 * @remarks
 * This hook enhances the backend from useBackend() with correlation metadata
 * from the nearest CorrelationProvider.
 *
 * @param backend - optional backend override
 * @param correlationMetadata - optional correlation metadata to merge with the context data
 * @public
 */
export declare const useBackendWithCorrelation: (backend?: IAnalyticalBackend, correlationMetadata?: IRequestCorrelationMetadata) => IAnalyticalBackend | undefined;
/**
 * Combined provider for both backend and correlation metadata.
 *
 * @public
 */
export interface IBackendProviderWithCorrelationProps {
    /**
     * Backend instance to use or enhance with correlation
     */
    backend?: IAnalyticalBackend;
    /**
     * Key-value pairs of correlation metadata to be used for telemetry
     */
    correlationData: IRequestCorrelationMetadata;
    /**
     * React children
     */
    children?: React.ReactNode;
}
/**
 * Combined provider for both backend and correlation metadata.
 * This is a convenience component that wraps BackendProvider and CorrelationProvider
 * to provide both a backend instance and correlation metadata to components.
 *
 * @public
 */
export declare const BackendProviderWithCorrelation: React.FC<IBackendProviderWithCorrelationProps>;
//# sourceMappingURL=CorrelationContext.d.ts.map