// (C) 2019-2025 GoodData Corporation
import { invariant } from "ts-invariant";
import { createExecution } from "./createExecution.js";
import { DataViewFacade } from "../base/index.js";
/**
 * DataViewLoader allows you to speficy, load and access data results with convenient series and slices API.
 *
 * @alpha
 */
export class DataViewLoader {
    backend;
    workspace;
    options;
    constructor(backend, workspace, options = {}) {
        this.backend = backend;
        this.workspace = workspace;
        this.options = options;
    }
    /**
     * Creates a new instance of the DataViewLoader for particular backend and workspace.
     *
     * @alpha
     */
    static for(backend, workspace) {
        return new DataViewLoader(backend, workspace);
    }
    /**
     * Data series will be built using the provided measures that are further scoped for
     * elements of the specified attributes.
     *
     * @remarks
     * You must define at least 1 measure for the series.
     *
     * @alpha
     */
    seriesFrom = (...measuresAndScopingAttributes) => {
        return this.newLoaderWithOptions({ seriesBy: measuresAndScopingAttributes });
    };
    /**
     * Slice all data series by elements of these attributes.
     *
     * @alpha
     */
    slicesFrom = (...attributes) => {
        return this.newLoaderWithOptions({ slicesBy: attributes });
    };
    /**
     * Filters to apply on server side.
     *
     * @alpha
     */
    filterBy = (...filters) => {
        return this.newLoaderWithOptions({ filters });
    };
    /**
     * Sorting to apply on server side.
     *
     * @alpha
     */
    sortBy = (...sorts) => {
        return this.newLoaderWithOptions({ sortBy: sorts });
    };
    /**
     * Include these totals among the data slices.
     *
     * @alpha
     */
    withTotals = (...totals) => {
        return this.newLoaderWithOptions({ totals });
    };
    /**
     * Runs execution with the provided AbortSignal.
     *
     * @alpha
     */
    withSignal = (signal) => {
        return this.newLoaderWithOptions({ signal });
    };
    /**
     * Loads subset of the result data and wraps them in {@link DataViewFacade}.
     *
     * @alpha
     */
    loadWindow = async (dataWindow) => {
        const result = await this.loadResult();
        const dataView = await result.readWindow(dataWindow.offset, dataWindow.size);
        return DataViewFacade.for(dataView);
    };
    /**
     * Loads all the result data and wraps them in {@link DataViewFacade}.
     *
     * @alpha
     */
    loadAll = async () => {
        const result = await this.loadResult();
        const dataView = await result.readAll();
        return DataViewFacade.for(dataView);
    };
    loadResult = async () => {
        invariant(this.options.seriesBy, "You need to specify series before loading the results.");
        let execution = createExecution({
            backend: this.backend,
            workspace: this.workspace,
            seriesBy: this.options.seriesBy,
            componentName: "DataViewLoader",
            ...this.options,
        });
        if (this.options.signal) {
            execution = execution.withSignal(this.options.signal);
        }
        return execution.execute();
    };
    newLoaderWithOptions = (options) => {
        return new DataViewLoader(this.backend, this.workspace, { ...this.options, ...options });
    };
}
//# sourceMappingURL=DataViewLoader.js.map