import { DataViewFacade, useBackendStrict, useWorkspaceStrict, useResolveValuesWithPlaceholders, useCancelablePromise, convertError, } from "../base/index.js";
import isEmpty from "lodash/isEmpty.js";
import { createExecution } from "./createExecution.js";
/**
 * @internal
 */
function isExecutionConfiguration(obj) {
    return !isEmpty(obj) && !!obj?.seriesBy;
}
/**
 * React hook to get data for a specific execution.
 *
 * @public
 */
export function useExecutionDataView(config, deps) {
    const { execution, window, enableExecutionCancelling = false, onCancel, onError, onLoading, onPending, onSuccess, } = config;
    const backend = useBackendStrict(config.backend, "useExecutionDataView");
    const workspace = useWorkspaceStrict(config.workspace, "useExecutionDataView");
    const effectiveDeps = deps ?? [];
    const propsToResolve = getExecutionConfigurationProps(config.execution);
    const [seriesBy, slicesBy, totals, filters, sortBy] = useResolveValuesWithPlaceholders([
        propsToResolve.seriesBy,
        propsToResolve.slicesBy,
        propsToResolve.totals,
        propsToResolve.filters,
        propsToResolve.sortBy,
    ], propsToResolve.placeholdersResolutionContext);
    const preparedExecution = isExecutionConfiguration(execution)
        ? createExecution({
            ...execution,
            seriesBy: seriesBy,
            slicesBy,
            totals,
            filters,
            sortBy,
            backend,
            workspace,
        })
        : execution;
    return useCancelablePromise({
        enableAbortController: enableExecutionCancelling,
        promise: preparedExecution
            ? (signal) => {
                let effectiveExecution = preparedExecution;
                if (enableExecutionCancelling) {
                    effectiveExecution = preparedExecution.withSignal(signal);
                }
                return effectiveExecution
                    .execute()
                    .then((executionResult) => window
                    ? executionResult.readWindow(window.offset, window.size)
                    : executionResult.readAll())
                    .then((dataView) => {
                    return DataViewFacade.for(dataView);
                })
                    .catch((error) => {
                    throw convertError(error);
                });
            }
            : null,
        onCancel,
        onError,
        onLoading,
        onPending,
        onSuccess,
    }, [
        backend,
        workspace,
        preparedExecution?.fingerprint() ?? "__executionFingerprint__",
        window?.offset ?? "__offset__",
        window?.size ?? "__size__",
        enableExecutionCancelling,
        ...effectiveDeps,
    ]);
}
/**
 * @internal
 */
function getExecutionConfigurationProps(execution) {
    if (isExecutionConfiguration(execution)) {
        return execution;
    }
    return {};
}
//# sourceMappingURL=useExecutionDataView.js.map